==> zio-aws-lakeformation_2.13-5.17.104.13-sources.jar: zio/aws/lakeformation/model/BatchRevokePermissionsRequest.scala <==
package zio.aws.lakeformation.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.lakeformation.model.primitives.CatalogIdString
import scala.jdk.CollectionConverters._
final case class BatchRevokePermissionsRequest(
    catalogId: Option[CatalogIdString] = None,
    entries: Iterable[zio.aws.lakeformation.model.BatchPermissionsRequestEntry]
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lakeformation.model.BatchRevokePermissionsRequest = {
    import BatchRevokePermissionsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lakeformation.model.BatchRevokePermissionsRequest
      .builder()
      .optionallyWith(
        catalogId.map(value => CatalogIdString.unwrap(value): java.lang.String)
      )(_.catalogId)
      .entries(entries.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .build()
  }
  def asReadOnly
      : zio.aws.lakeformation.model.BatchRevokePermissionsRequest.ReadOnly =
    zio.aws.lakeformation.model.BatchRevokePermissionsRequest
      .wrap(buildAwsValue())
}
object BatchRevokePermissionsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lakeformation.model.BatchRevokePermissionsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lakeformation.model.BatchRevokePermissionsRequest =
      zio.aws.lakeformation.model.BatchRevokePermissionsRequest(
        catalogId.map(value => value),
        entries.map { item =>
          item.asEditable
        }
      )
    def catalogId: Option[CatalogIdString]
    def entries: List[
      zio.aws.lakeformation.model.BatchPermissionsRequestEntry.ReadOnly
    ]
    def getCatalogId: ZIO[Any, AwsError, CatalogIdString] =
      AwsError.unwrapOptionField("catalogId", catalogId)
    def getEntries: ZIO[Any, Nothing, List[
      zio.aws.lakeformation.model.BatchPermissionsRequestEntry.ReadOnly
    ]] = ZIO.succeed(entries)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lakeformation.model.BatchRevokePermissionsRequest
  ) extends zio.aws.lakeformation.model.BatchRevokePermissionsRequest.ReadOnly {
    override val catalogId: Option[CatalogIdString] = scala
      .Option(impl.catalogId())
      .map(value =>
        zio.aws.lakeformation.model.primitives.CatalogIdString(value)
      )
    override val entries: List[
      zio.aws.lakeformation.model.BatchPermissionsRequestEntry.ReadOnly
    ] = impl
      .entries()
      .asScala
      .map { item =>
        zio.aws.lakeformation.model.BatchPermissionsRequestEntry.wrap(item)
      }
      .toList
  }
  def wrap(
      impl: software.amazon.awssdk.services.lakeformation.model.BatchRevokePermissionsRequest
  ): zio.aws.lakeformation.model.BatchRevokePermissionsRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-lakeformation_2.13-5.17.205.1-sources.jar: zio/aws/lakeformation/model/BatchRevokePermissionsRequest.scala <==
package zio.aws.lakeformation.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.lakeformation.model.primitives.CatalogIdString
import scala.jdk.CollectionConverters._
final case class BatchRevokePermissionsRequest(
    catalogId: Optional[CatalogIdString] = Optional.Absent,
    entries: Iterable[zio.aws.lakeformation.model.BatchPermissionsRequestEntry]
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lakeformation.model.BatchRevokePermissionsRequest = {
    import BatchRevokePermissionsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lakeformation.model.BatchRevokePermissionsRequest
      .builder()
      .optionallyWith(
        catalogId.map(value => CatalogIdString.unwrap(value): java.lang.String)
      )(_.catalogId)
      .entries(entries.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .build()
  }
  def asReadOnly
      : zio.aws.lakeformation.model.BatchRevokePermissionsRequest.ReadOnly =
    zio.aws.lakeformation.model.BatchRevokePermissionsRequest
      .wrap(buildAwsValue())
}
object BatchRevokePermissionsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lakeformation.model.BatchRevokePermissionsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lakeformation.model.BatchRevokePermissionsRequest =
      zio.aws.lakeformation.model.BatchRevokePermissionsRequest(
        catalogId.map(value => value),
        entries.map { item =>
          item.asEditable
        }
      )
    def catalogId: Optional[CatalogIdString]
    def entries: List[
      zio.aws.lakeformation.model.BatchPermissionsRequestEntry.ReadOnly
    ]
    def getCatalogId: ZIO[Any, AwsError, CatalogIdString] =
      AwsError.unwrapOptionField("catalogId", catalogId)
    def getEntries: ZIO[Any, Nothing, List[
      zio.aws.lakeformation.model.BatchPermissionsRequestEntry.ReadOnly
    ]] = ZIO.succeed(entries)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lakeformation.model.BatchRevokePermissionsRequest
  ) extends zio.aws.lakeformation.model.BatchRevokePermissionsRequest.ReadOnly {
    override val catalogId: Optional[CatalogIdString] = zio.aws.core.internal
      .optionalFromNullable(impl.catalogId())
      .map(value =>
        zio.aws.lakeformation.model.primitives.CatalogIdString(value)
      )
    override val entries: List[
      zio.aws.lakeformation.model.BatchPermissionsRequestEntry.ReadOnly
    ] = impl
      .entries()
      .asScala
      .map { item =>
        zio.aws.lakeformation.model.BatchPermissionsRequestEntry.wrap(item)
      }
      .toList
  }
  def wrap(
      impl: software.amazon.awssdk.services.lakeformation.model.BatchRevokePermissionsRequest
  ): zio.aws.lakeformation.model.BatchRevokePermissionsRequest.ReadOnly =
    new Wrapper(impl)
}
